# Constants and Material Properties

## Physical Constants
::: fdtdx.core.physics.constants.c
::: fdtdx.core.physics.constants.mu0
::: fdtdx.core.physics.constants.eps0
::: fdtdx.core.physics.constants.eta0
::: fdtdx.core.physics.constants.wavelength_to_period

## Material Properties
::: fdtdx.core.physics.constants.relative_permittivity_air
::: fdtdx.core.physics.constants.relative_permittivity_substrate
::: fdtdx.core.physics.constants.relative_permittivity_polymer
::: fdtdx.core.physics.constants.relative_permittivity_silicon
::: fdtdx.core.physics.constants.relative_permittivity_silica
::: fdtdx.core.physics.constants.relative_permittivity_SZ_2080
::: fdtdx.core.physics.constants.relative_permittivity_ma_N_1400_series
::: fdtdx.core.physics.constants.relative_permittivity_bacteria
::: fdtdx.core.physics.constants.relative_permittivity_water
::: fdtdx.core.physics.constants.relative_permittivity_fused_silica
::: fdtdx.core.physics.constants.relative_permittivity_coated_silica
::: fdtdx.core.physics.constants.relative_permittivity_resin
::: fdtdx.core.physics.constants.relative_permittivity_ormo_prime

## Material Configurations
::: fdtdx.core.physics.constants.silicon_permittivity_config
::: fdtdx.core.physics.constants.standard_permittivity_config
::: fdtdx.core.physics.constants.higher_permittivity_config
::: fdtdx.core.physics.constants.silica_permittivity_config
::: fdtdx.core.physics.constants.multi_material_permittivity_config
::: fdtdx.core.physics.constants.multi_material_qd_permittivity_config
